@@ -1,5 +1,9 @@
 import sys
-from collections import MutableMapping
+
+try:
+    from collections.abc import MutableMapping
+except ImportError:
+    from collections import MutableMapping
 
 from . import DEFAULT_LTI_VERSION
 
